# Instructions 

#### This is our test project. 
#### Please install this package 
```
pip install functions-by-madina3006
```

#### You can also install older version 
```
pip install functions-by-madina3006==VERSION_NUMBER
```